==> nextcloud-12.0.2.tgz: nextcloud/apps/files_texteditor/l10n/ru.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "сохранение...",
    "saved!" : "сохранен!",
    "failed!" : "ошибка!",
    "Saved" : "Сохранено",
    "There was a problem saving your changes. Click to resume editing." : "Произошла ошибка во время сохранения изменений. Нажмите для продолжения редактирования.",
    "An error occurred!" : "Произошла ошибка!",
    "Edit" : "Править",
    "Mixed" : "Смешанный",
    "Preview" : "Предварительный просмотр",
    "New text file" : "Новый текстовый файл",
    "New text file.txt" : "Новый текстовый документ.txt",
    "You can not open a folder" : "Вы не можете открыть каталог",
    "This file is too big to be opened. Please download the file instead." : "Файл слишком большой для открытия. Пожалуйста скачайте его.",
    "Cannot read the file." : "Не удается прочитать файл.",
    "Invalid file path supplied." : "Указан некорректный путь.",
    "The file is locked." : "Файл заблокирован.",
    "An internal server error occurred." : "Произошла внутренняя ошибка сервера.",
    "You can not write to a folder" : "Вы не можете записать в каталог",
    "Cannot save file as it has been modified since opening" : "Невозможно сохранить файл поскольку он был изменен после открытия ",
    "Insufficient permissions" : "Недостаточно прав доступа",
    "File path not supplied" : "Неизвестен путь файла",
    "File mtime not supplied" : "Неизвестно время модификации файла",
    "Text editor" : "Редактор текста",
    "Text file" : "Текстовый файл"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/files_texteditor/l10n/ru.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "сохранение...",
    "saved!" : "сохранено!",
    "failed!" : "ошибка!",
    "Saved" : "Сохранено",
    "There was a problem saving your changes. Click to resume editing." : "Во время сохранения изменений произошла ошибка . Нажмите для продолжения редактирования.",
    "An error occurred!" : "Произошла ошибка!",
    "Edit" : "Править",
    "Mixed" : "Смешанный",
    "Preview" : "Предварительный просмотр",
    "New text file" : "Новый текстовый файл",
    "New text file.txt" : "Новый текстовый документ.txt",
    "You can not open a folder" : "Вы не можете открыть каталог",
    "This file is too big to be opened. Please download the file instead." : "Файл слишком большой для открытия. Пожалуйста скачайте его.",
    "Cannot read the file." : "Не удается прочитать файл.",
    "Invalid file path supplied." : "Указан некорректный путь.",
    "The file is locked." : "Файл заблокирован.",
    "An internal server error occurred." : "Произошла внутренняя ошибка сервера.",
    "You can not write to a folder" : "Вы не можете записать в каталог",
    "Cannot save file as it has been modified since opening" : "Невозможно сохранить файл поскольку он был изменен после открытия ",
    "Insufficient permissions" : "Недостаточно прав доступа",
    "File path not supplied" : "Неизвестен путь файла",
    "File mtime not supplied" : "Неизвестно время модификации файла",
    "Text editor" : "Редактор текста"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
